# Permission to Relicense under MPLv2 or any other OSI approved license chosen by the current PyZMQ BDFL

This is a statement by Julian Taylor
that grants permission to relicense its copyrights in the Python ZeroMQ bindings
(pyzmq) under the Mozilla Public License v2 (MPLv2) or any other
Open Source Initiative approved license chosen by the current PyZMQ
BDFL (Benevolent Dictator for Life).

A portion of the commits made by the GitHub handle "juliantaylor", with
commit author "Julian Taylor <jtaylor.debian@googlemail.com>", are copyright of Julian Taylor.
This document hereby grants the libzmq project team to relicense libzmq,
including all past, present and future contributions of the author listed above.

Julian Taylor
2017/07/19
